Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'jest.config.base.js')
-rw-r--r--jest.config.base.js9
1 files changed, 7 insertions, 2 deletions
diff --git a/jest.config.base.js b/jest.config.base.js
index 18c13293275..8642cc22b0b 100644
--- a/jest.config.base.js
+++ b/jest.config.base.js
@@ -233,8 +233,13 @@ module.exports = (path, options = {}) => {
collectCoverageFrom,
coverageDirectory: coverageDirectory(),
coverageReporters: ['json', 'lcov', 'text-summary', 'clover'],
- // We need ignore _worker code coverage since we are manually transforming it
- coveragePathIgnorePatterns: ['<rootDir>/node_modules/', '_worker\\.js$'],
+ coveragePathIgnorePatterns: [
+ '<rootDir>/node_modules/',
+ // We need ignore _worker code coverage since we are manually transforming it
+ '_worker\\.js$',
+ // we're using import.meta in main entrypoint with Vite which confuses Babel, so we just ignore it
+ '<rootDir>/app/assets/javascripts/entrypoints/main',
+ ],
cacheDirectory: '<rootDir>/tmp/cache/jest',
modulePathIgnorePatterns: ['<rootDir>/.yarn-cache/'],
reporters,